from typing import Optional

from ..persistence import PersistDNSLogs
from ..settings import DNS_LOGLINE_FIELDS
from ..parsers import format_dns_logline
from ..settings import FILTER_SERVER


class PDNSRecursorMixin:
    """
    Tail PDNS Recursor resolution logs
    """
    name = 'dns_recursor'
    ws_channel = ''
    offset_file = '/var/tmp/dns_recursor.offset'
    watch_file = '/var/log/pdns_recursor.log'
    persist_class = PersistDNSLogs
    csv_fields = DNS_LOGLINE_FIELDS

    def as_data(self, line: str) -> Optional[dict]:
        """
        If line is of interest, format it
        so it can be parsed by csv library.
        """
        if not FILTER_SERVER:
            return

        formatted = format_dns_logline(line)
        if not formatted:
            return

        return super().as_data(formatted)
